**************************************************************************
**************************************************************************
**                                                                      **
** This is the syntax necessary to replicate results from Moscardelli   **
** and Becker, "Not on Your (Half) Life:  The Partisan Geography of     **
** Nuclear Waste Disposal."                                             **
**                                                                      **
** The models in the paper were estimated using STATA 9.                **
**                                                                      **
** Authors' contact information:                                        **
**                                                                      **
** Vincent G. Moscardelli (vmoscardelli@polsci.umass.edu)               **
** Lawrence C. Becker (lawrence.becker@csun.edu)                        **
**                                                                      **
**************************************************************************
**************************************************************************

. use "C:\ . . .\Yucca_Mtn_Tables_1_and_2_Replication_Reduced.dta", clear

label var state "State (string)"
label var st_code "State (ICPSR)"
label var party "Party (ICPSR)"
label var app_ewd "Energy and Water Dev. Subcommittee"
label var enr "Energy and Natural Resources"
label var epw "Environment and Public Works"
label var tc_orig "Casks Originating in State"
label var ptybin_d "Party (Democrat=1)"
label var dum100 "100th Congress (dummy)"
label var dum104 "104th Congress (dummy)"
label var dum105 "105th Congress (dummy)"
label var dum106 "106th Congress (dummy)"
label var lcvallp "LCV Rating"
label var demldr3 "Democratic Party Leader"
label var gopldr3 "Republican Party Leader"
label var tctsroos "Casks Shipped Through State per Annum"
label var altsite2 "Alternative Site"
label var depvar "Reid Support Score (DV)"
label var demx104 "Interaction of Party and 104th Congress"
label var demx105 "Interaction of Party and 105th Congress"
label var demx106 "Interaction of Party and 106th Congress"
label var nei_eei "Contributions from Nuclear Energy Institute"
label var hr10456d "1995-2000 Period (dummy)"
label var demx456 "Interaction of Party and 1995-2000 Time Period"
label var noturn100to106 "Constant Membership, 1987-2000 (dummy)"
label var turn100to106 "Seats Experiencing Turnover, 1987-2000 (dummy)"

. save "C:\ . . .\Yucca_Mtn_Tables_1_and_2_Replication_Reduced.dta", replace

. codebook

*Replicate Table 1

sum depvar if ptybin_d==1 & membid~=15054 & congress==100
sum depvar if ptybin_d==0 & membid~=15054 & congress==100


regress depvar ptybin_d if congress==100
regress depvar ptybin_d if congress>100

*Replicate Table 2

*Model 1

regress depvar ptybin_d demldr3 gopldr3  hr10456d demx456 tc_orig tctsroos altsite2 nei_eei lcvallp app_ewd enr epw if membid ~= 15054, cluster(membid)


*Replicate Model 2

regress depvar ptybin_d demldr3 gopldr3 dum104 dum105 dum106 demx104 demx105 demx106 tc_orig tctsroos altsite2 nei_eei lcvallp app_ewd enr epw if membid ~= 15054, cluster(membid)


*Replicate Model 3


regress depvar ptybin_d demldr3 gopldr3 dum104 dum105 dum106 demx104 demx105 demx106 tc_orig tctsroos altsite2 nei_eei lcvallp app_ewd enr epw if membid ~= 15054 & noturn100to106 == 1, cluster(membid)


*Replicate Model 4

regress depvar ptybin_d demldr3 gopldr3 dum104 dum105 dum106 demx104 demx105 demx106 tc_orig tctsroos altsite2 nei_eei lcvallp app_ewd enr epw if membid ~= 15054 & turn100to106 == 1, cluster(membid)



. use "C:\ . . .\Yucca_Mtn_Table_3_Replication_Reduced.dta", clear

*Add variable labels

label var ptybin_d "Party (Democrat=1)"
label var demldr3 "Democratic Party Leader"
label var gopldr3 "Republican Party Leader"
label var app_ewd "Energy and Water Dev. Subcommittee"
label var enr "Energy and Natural Resources"
label var epw "Environment and Public Works"
label var lcv_a "LCV Rating"
label var origtruk "Casks Originating in State"
label var tctsroos "Casks Shipped Through State Per Annum"
label var v107_167 "S.J. Res. 34 (DV)"
label var nei_tot "Contributions from Nuclear Energy Institute"
label var altsite2 "Alternative Site"

. save "C:\ . . .\Yucca_Mtn_Table_3_Replication_Reduced.dta", replace

*Replicate Table 3

logistic v107_167 origtruk tctsroos altsite2 app_ewd enr epw ptybin_d lcv_a demldr3 nei_tot if membid ~= 15054, cluster(st_code)

logistic

pre

lstat

prchange

